@@ -94,7 +94,7 @@
 #'   to a local backup
 #' @param title The title of the diagram
 #' @param outputFile If specified, the ABCD is written to
-#'   this file.
+#'   this file using [DiagrammeR::export_graph].
 #' @param outputWidth,outputHeight If an `outputFile` is
 #'   specified, these determine its width and height (in pixels)
 #' @param includeColNames Whether to include the column names
@@ -104,47 +104,58 @@
 #'   labels.
 #' @param silent Whether to suppress (`TRUE`) or show
 #'   (`FALSE`) more detailed information.
+#' @param returnGraphOnly Whether to return the full results
+#'   object or only the [DiagrammeR::DiagrammeR] graph.
 #' @param regExReplacements A list of pairs of regular
 #'   expressions that will be applied to the specifications
 #'   before generating the ABCD. This can be used to sanitize
 #'   problematic characters (e.g. ', " and \).
+#' @param x The ABCD object to print (as generated by a call to `abcd`).
+#' @param width,height Width and height to use when printing the ABCD.
+#' @param \dots Any additional arguments are passed on to
+#' [DiagrammeR::render_graph()].
 #'
 #' @return A list consisting of an `input`, `intermediate`, and
 #'   `output` list, where the ABCD is stored in the `output` list
-#'   as `graph`.
+#'   as a [DiagrammeR::DiagrammeR] called `graph`.
 #' @author
 #'   Gjalt-Jorn Peters, \email{gjalt-jorn@@a-bc.eu}, with
-#'   contributions from Matti Heino.
+#'   contributions from Matti Heino and Sander Eggers.
 #' @references
 #'   Crutzen, R., & Peters, G.-J. Y. (2018). Evolutionary
 #'   learning processes as the foundation for behaviour change.
-#'   Health Psychology Review, 12(1), 43–57.
+#'   *Health Psychology Review,* 12(1), 43–57.
 #'   https://doi.org/10.1080/17437199.2017.1362569
 #'
 #'   Kok, G. (2014). A practical guide to effective behavior
 #'   change: How to apply theory- and evidence-based behavior
-#'   change methods in an intervention. European Health Psychologist,
+#'   change methods in an intervention. *European Health Psychologist*,
 #'   16(5), 156–170. https://doi.org/10.31234/osf.io/r78wh
 #'
 #'   Kok, G., Gottlieb, N. H., Peters, G.-J. Y., Mullen,
 #'   P. D., Parcel, G. S., Ruiter, R. A. C., … Bartholomew,
 #'   L. K. (2016). A taxonomy of behavior change methods:
-#'   an Intervention Mapping approach. Health Psychology
-#'   Review, 10(3), 297–312.
+#'   an Intervention Mapping approach. *Health Psychology
+#'   Review*, 10(3), 297–312.
 #'   https://doi.org/10.1080/17437199.2015.1077155
 #'
 #'   Peters, G.-J. Y., et al. (2019) The core of
 #'   behavior change: introducing the Acyclic Behavior Change
 #'   Diagram to report and analyze interventions.
-#' @examples ### Partial acyclic behavior change diagram of only
+#' @examples ### Using 'print' to prevent pkgdown() from choking
+#' ### Partial acyclic behavior change diagram of only
 #' ### one performance objective (sub-behavior)
-#' behaviorchange::abcd(abcd_specs_single_po);
-#'
-#' ### Full acyclic behavior change diagram
-#' behaviorchange::abcd(abcd_specs_full);
+#' ### (using the 'abcd_specs_single_po_without_conditions'
+#' ###  dataset in this package)
+#' print(behaviorchange::abcd(behaviorchange::abcd_specs_single_po_without_conditions));
 #'
+#' ### Acyclic behavior change diagram including multiple
+#' ### sub-behaviors (performance objectives)
+#' ### (using the 'abcd_specs_complete' dataset in this
+#' ###  package)
+#' print(behaviorchange::abcd(behaviorchange::abcd_specs_complete));
+#' @rdname abcd
 #' @export
-
 abcd <- function(specs,
                  specCols = c('bcps', 'cnds', 'apps', 'sdts', 'dets', 'pobs', 'behs'),
                  omitColOrder = c('cnds', 'behs', 'bcps', 'apps'),
@@ -156,6 +167,7 @@ abcd <- function(specs,
                  includeColNames = TRUE,
                  maxLabelLength = 30,
                  silent = FALSE,
+                 returnGraphOnly = FALSE,
                  regExReplacements = list(c("\\\"", "`"),
                                           c("\\'", "`"),
                                           c("\\\\", "/"))) {
@@ -586,99 +598,100 @@ abcd <- function(specs,
   ### Create final graph, set attributes, and return the result
   ######################################################################
 
-  res$output$graph <-
+  graph <-
     DiagrammeR::create_graph(nodes_df = final_nodeDf,
                              edges_df = final_edgeDf,
                              graph_name = title);
 
-  res$output$graph <-
-    DiagrammeR::add_global_graph_attrs(res$output$graph,
-                                       "layout",
-                                       "dot", "graph");
-  res$output$graph <-
-    DiagrammeR::add_global_graph_attrs(res$output$graph,
-                                       "rankdir",
-                                       "LR", "graph");
-  res$output$graph <-
-    DiagrammeR::add_global_graph_attrs(res$output$graph,
-                                       "outputorder",
-                                       "nodesfirst", "graph");
+  graph <-
+    DiagrammeR::add_global_graph_attrs(graph,
+                                       "layout", "dot",
+                                       "graph");
+  graph <-
+    DiagrammeR::add_global_graph_attrs(graph,
+                                       "rankdir", "LR",
+                                       "graph");
+  graph <-
+    DiagrammeR::add_global_graph_attrs(graph,
+                                       "outputorder", "nodesfirst",
+                                       "graph");
 
   if (!is.null(outputFile)) {
     for (currentFile in outputFile) {
-      DiagrammeR::export_graph(res$output$graph,
+      DiagrammeR::export_graph(graph,
                                file_name = currentFile,
                                file_type = tools::file_ext(currentFile),
                                width=outputWidth,
                                height=outputHeight,
-                               title = DiagrammeR::get_graph_name(res$output$graph));
+                               title = DiagrammeR::get_graph_name(graph));
     }
   }
 
-  class(res) <- "abcdiagram";
-
-  return(res);
+  if (returnGraphOnly) {
+    return(graph);
+  } else {
+    res$output$graph <- graph;
+    class(res) <- "abcdiagram";
+    return(res);
+  }
 
 }
 
+#' @rdname abcd
+#' @method print abcdiagram
 #' @export
-print.abcdiagram <- function(x, ...) {
-  print(DiagrammeR::render_graph(x$output$graph,
-                                 width=x$input$width,
-                                 height=x$input$height,
-                                 title = DiagrammeR::get_graph_name(x$output$graph)),
-        ...);
+print.abcdiagram <- function(x,
+                             width=x$input$width,
+                             height=x$input$height,
+                             title = DiagrammeR::get_graph_name(x$output$graph),
+                             ...) {
+  return(DiagrammeR::render_graph(x$output$graph,
+                                  width=width,
+                                  height=height,
+                                  title=title,
+                                  ...));
 }
 
-#' Two simple example datasets for ABCD's
+#' Simple example datasets for ABCD's
 #'
-#' This are two (nested) datasets illustrating the logic model of change for
+#' This are three (nested) datasets illustrating the logic model of change for
 #' a simple condom use intervention in a way that can be visualised using
-#' the [abcd] function. The full dataset is `abcd_specs_full`, and a subset
-#' that only contains the information about one sub-behavior (performance
-#' objective) is available as `abcd_specs_single_po`. The variables in the full
+#' the [abcd] function. The full dataset is `abcd_specs_full`, a subset
+#' that does not explicitly include the conditions for effectiveness
+#' (instead showing letters that can then be explained in, for example,
+#' the manuscript text) is called `abcd_specs_without_conditions`, and
+#' a version that only contains the information about one sub-behavior
+#' (performance objective) is available as
+#' `abcd_specs_single_po_without_conditions`. The variables in the full
 #' dataset are:
 #'
 #' * `Behavior Change Principles`: The behavior change principles (BCPs), also known as methods for behavior change or 'behavior change techniques' (BCTs), that describe the psychological principles that are assumed to realise the change in the (sub-)determinants.
+#' * `Conditions for effectiveness\\n(e.g. parameters for use)`: The conditions for effectiveness that describe the constraints and considerations taken into account in the translation of the BCPs to practical applications for the relevant target population, context, culture, etc.
 #' * `Applications`: The applications of these BCPs. Where the BCPs describe theoretical principles, the applications are more or less tangible intervention elements.
 #' * `Sub-determinants\\n(e.g. beliefs; can be formulated as Change Objectives)`: The specific aspects of teh target population's psychology that are targeted by the BCPs (e.g. beliefs, or in Intervention Mapping vocabulary, Change Objectives).
 #' * `Determinants`: The determinants, psychological constructs, that the targeted sub-determinants are a part of, and that together predict the Performance Objectives (sub-behaviors).
 #' * `Performance Objectives`: Explicitly defined sub-behaviors at a level of specificity that distinguishes them from other sub-behaviors, and that together form the target behavior.
 #' * `Target Behavior`: The ultimate target behavior, usually defined at a relatively general level.
 #'
+#' In addition to these three datasets, a Dutch example specification
+#' is included named `abcd_specs_dutch_xtc`.
+#'
 #' @docType data
-#' @aliases abcd_specs_full abcd_specs_single_po
+#' @aliases abcd_specs_complete abcd_specs_without_conditions abcd_specs_single_po_without_conditions abcd_specs_dutch_xtc
 #' @keywords data
 #' @name abcd_specs_examples
-#' @usage data(abcd_specs_full)
-#' @usage data(abcd_specs_single_po)
-#' @format For `abcd_specs_full`, a data frame with 6 variables and 7 rows;
-#' for `abcd_specs_single_po`, a data frame with 5 variables and 4 rows.
-c("abcd_specs_single_po", "abcd_specs_full");
+#' @usage data(abcd_specs_complete)
+#' @usage data(abcd_specs_without_conditions)
+#' @usage data(abcd_specs_single_po_without_conditions)
+#' @format For `abcd_specs_complete`, a data frame with 7 variables and 7 rows;
+#' for `abcd_specs_without_conditions`, a data frame with 6 variables and 7 rows;
+#' for `abcd_specs_single_po_without_conditions`, a data frame with 5 variables and 4 rows;
+c("abcd_specs_complete",
+  "abcd_specs_without_conditions",
+  "abcd_specs_single_po_without_conditions",
+  "abcd_specs_dutch_xtc");
 
-# abcd_specs_single_po <-
-#   data.frame(c("Social comparison",
-#                "Persuasive communication",
-#                "Modeling",
-#                "Guided practice"),
-#              c("A chart showing percentage of people using condoms.",
-#                "Quotations from people expressing approval.",
-#                "A role model illustrates bringing up condoms in different settings.",
-#                "In a mini-game, target population individuals practice negotiation."),
-#              c("Most people use condoms.",
-#                "Most people approve of me suggesting to use condoms.",
-#                "It is easy for me to bring up condoms.",
-#                "If my partner is not enthusiastic, I know I can persuade them."),
-#              c("Perceived Norms",
-#                "Perceived Norms",
-#                "Self-efficacy",
-#                "Self-efficacy"),
-#              c("Negotiate condom use",
-#                "Negotiate condom use",
-#                "Negotiate condom use",
-#                "Negotiate condom use"));
-#
-# abcd_specs_full <-
+# abcd_specs_complete <-
 #   data.frame(c("Persuasive communication",
 #                "Persuasive communication",
 #                "Persuasive communication",
@@ -686,6 +699,13 @@ c("abcd_specs_single_po", "abcd_specs_full");
 #                "Persuasive communication",
 #                "Modeling",
 #                "Guided practice"),
+#              c("Research in this target population showed that infographics are perceived as trustworthy and are generally well-received.",
+#                "Research in this target population showed that infographics are perceived as trustworthy and are generally well-received.",
+#                "Showing such quotations yielded promising effects in a similar interventions in this population.",
+#                "Chart allow comparing percentages of people using condoms allow showing frequencies, which people can process better then probabilities.",
+#                "Showing such quotations yielded promising effects in a similar interventions in this population.",
+#                "We selected role models from the target populations, and the modeling scripts were developed to demonstrate strategies to deal with the most common scenarios.",
+#                "A mini-game allows for the desired interactivity, and this mini-game can piggy-back on coordinated efforts from this other campaign that people are doing."),
 #              c("An infographic explains how condoms work.",
 #                "An infographic explains how condoms work.",
 #                "Quotations from people expressing approval.",
@@ -723,32 +743,91 @@ c("abcd_specs_single_po", "abcd_specs_full");
 #                "Condom use"),
 #              stringsAsFactors = FALSE);
 #
-# names(abcd_specs_full) <-
+# names(abcd_specs_complete) <-
 #   c('Behavior Change Principles',
+#     'Conditions for effectiveness\n(e.g. parameters for use)',
 #     'Applications',
 #     'Sub-determinants\n(e.g. beliefs; can be formulated as Change Objectives)',
 #     'Determinants',
 #     'Performance Objectives',
 #     'Target Behavior');
-# names(abcd_specs_single_po) <-
-#   names(abcd_specs_full)[1:5];
 #
-# devtools::use_data(abcd_specs_full, abcd_specs_single_po);
+# abcd_specs_without_conditions <-
+#   abcd_specs_complete[, c(1, 3:6)];
+#
+# abcd_specs_single_po_without_conditions <-
+#   abcd_specs_complete[5:7, c(1, 3:6)];
+#
+# names(abcd_specs_single_po_without_conditions)[5] <-
+#   'Behavior';
+#
+# devtools::use_data(abcd_specs_complete,
+#                    abcd_specs_without_conditions,
+#                    abcd_specs_single_po_without_conditions,
+#                    overwrite=TRUE);
+#
+# abcd_complete <-
+#   abcd(specs=c("https://docs.google.com/spreadsheets/d/1U1j-VoiK3WmfveJ7VpUMY_H9WNXDh85a8jKbM67AQSI/edit?usp=sharing",
+#                "C:/Sync/Data/R/tmp/library/tmp/abcd-complete.csv"),
+#        localBackup="C:/Sync/Data/R/tmp/abcd-complete.csv",
+#        outputFile=c("C:/Sync/Data/R/tmp/abcd-complete.svg",
+#                     "C:/Sync/Data/R/tmp/abcd-complete.png"));
+#
+# abcd_specs_without_conditions <-
+#   abcd(specs=c("https://docs.google.com/spreadsheets/d/13VE1_1Oa38CidDDbiuIw7ZP8DIJ2qzs_i8wlJ63YuMI",
+#                "C:/Sync/Data/R/tmp/abcd-without-conditions.csv"),
+#        localBackup="C:/Sync/Data/R/tmp/abcd-without-conditions.csv",
+#        outputFile=c("C:/Sync/Data/R/tmp/abcd-without-conditions.svg",
+#                     "C:/Sync/Data/R/tmp/abcd-without-conditions.png"));
+#
+# abcd_specs_single_po_without_conditions <-
+#   abcd(specs=c("https://docs.google.com/spreadsheets/d/1ib4CJlWUYcShwwue8kXq2519tTefK6T-orLarhuk0q0",
+#                "C:/Sync/Data/R/tmp/abcd_specs_single_po_without_conditions.csv"),
+#        localBackup="C:/Sync/Data/R/tmp/abcd_specs_single_po_without_conditions.csv",
+#        outputFile=c("C:/Sync/Data/R/tmp/abcd_specs_single_po_without_conditions.svg",
+#                     "C:/Sync/Data/R/tmp/abcd_specs_single_po_without_conditions.png"));
 
-# abcd_complete <- abcd(specs=c("https://docs.google.com/spreadsheets/d/1U1j-VoiK3WmfveJ7VpUMY_H9WNXDh85a8jKbM67AQSI/edit?usp=sharing",
-#                               "C:/Sync/Data/statistics/R/library/tmp/abcd-complete.csv"),
-#                       localBackup="C:/Sync/Data/statistics/R/library/tmp/abcd-complete.csv",
-#                       outputFile=c("C:/Sync/Data/statistics/R/library/tmp/abcd-complete.svg",
-#                                    "C:/Sync/Data/statistics/R/library/tmp/abcd-complete.png"));
+### Dutch example
+# abcd_specs_dutch_xtc <- googlesheets::gs_read(googlesheets::gs_url("https://docs.google.com/spreadsheets/d/1EKVqtG1kmf0ZxEvFUOBqUmakXTd9Ye3aSyZucBqiyRM/edit?usp=sharing"))
 #
-# abcd_full <- abcd(specs=c("https://docs.google.com/spreadsheets/d/13VE1_1Oa38CidDDbiuIw7ZP8DIJ2qzs_i8wlJ63YuMI",
-#                           "C:/Sync/Data/statistics/R/library/tmp/abcd-full.csv"),
-#                   localBackup="C:/Sync/Data/statistics/R/library/tmp/abcd-full.csv",
-#                   outputFile=c("C:/Sync/Data/statistics/R/library/tmp/abcd-full.svg",
-#                                "C:/Sync/Data/statistics/R/library/tmp/abcd-full.png"));
 #
-# abcd_single_po <- abcd(specs=c("https://docs.google.com/spreadsheets/d/1ib4CJlWUYcShwwue8kXq2519tTefK6T-orLarhuk0q0",
-#                                "C:/Sync/Data/statistics/R/library/tmp/abcd-single-po.csv"),
-#                        localBackup="C:/Sync/Data/statistics/R/library/tmp/abcd-single-po.csv",
-#                        outputFile=c("C:/Sync/Data/statistics/R/library/tmp/abcd-single-po.svg",
-#                                     "C:/Sync/Data/statistics/R/library/tmp/abcd-single-po.png"));
+# abcd_specs_dutch_xtc <-
+#   data.frame(c("Persuasieve communicatie",
+#                "Persuasieve communicatie",
+#                "Persuasieve communicatie",
+#                "Informatie over de goedkeuring van anderen",
+#                "Rolmodellen"),
+#              c("Boodschappen moeten relevant zijn, en niet teveel afwijken van wat de doelgroep gelooft; kan worden gestimuleerd met verrassing en herhaling; bevat argumenten.",
+#                "Boodschappen moeten relevant zijn, en niet teveel afwijken van wat de doelgroep gelooft; kan worden gestimuleerd met verrassing en herhaling; bevat argumenten.",
+#                "Boodschappen moeten relevant zijn, en niet teveel afwijken van wat de doelgroep gelooft; kan worden gestimuleerd met verrassing en herhaling; bevat argumenten.",
+#                "Anderen staan ook echt positief tegenover het doelgedrag.",
+#                "De doelgroep moet zich kunnen identificeren met het model; het model moet worstelen met het wenselijke gedrag; het model moet worden beloond voor het wenselijke gedrag."),
+#              c("Een infographic laat zien hoe de effecten van XTC veranderen als de dosis verandert.",
+#                "Een infographic laat zien hoe de effecten van XTC veranderen als de dosis verandert.",
+#                "Een infographic laat zien hoe de effecten van XTC veranderen als de dosis verandert.",
+#                "Het noemen van het Party Panel resultaat dat de meeste mensen lager willen doseren.",
+#                "Een comic met voorbeelden van gesprekken over dosering."),
+#              c("Als ik een hoge dosis XTC gebruik, dan voel ik me minder verbonden met anderen.",
+#                "Als ik een hoge dosis XTC gebruik, dan voel ik me meer geisoleerd.",
+#                "Als ik een hoge dosis XTC gebruik, dan onthoud ik minder.",
+#                "De meeste mensen staan goedkeurend tegenover het vermijden van een hoge dosis MDMA.",
+#                "Ik kan uitleggen waarom ik volgens de richtlijnen wil doseren."),
+#              c("Attitude", "Attitude", "Attitude", "Waargenomen norm", "Waargenomen gedragscontrole"),
+#              c("Besluiten een hoge dosis MDMA te willen vermijden",
+#                "Besluiten een hoge dosis MDMA te willen vermijden", "Besluiten een hoge dosis MDMA te willen vermijden",
+#                "Besluiten een hoge dosis MDMA te willen vermijden", "Met de uitgaansgroep van te voren bespreken welke dosis iedereen wil gebruiken"),
+#              c("XTC doseren volgens de richtlijnen",
+#                "XTC doseren volgens de richtlijnen",
+#                "XTC doseren volgens de richtlijnen",
+#                "XTC doseren volgens de richtlijnen",
+#                "XTC doseren volgens de richtlijnen"));
+#
+# names(abcd_specs_dutch_xtc) <-
+#   c("Gedragsveranderingsprincipes (`Behavior Change Principles`, BCPs, zoals methoden, BCTs, etc)",
+#     "Voorwaarden voor effectiviteit (`parameters for use`)",
+#     "Toepassingen (`applications`)",
+#     "Sub-determinanten (opvattingen, bv. beliefs; kunnen worden geformuleerd als Change Objectives)",
+#     "Determinanten",
+#     "Sub-gedragingen (`Performance Objectives`)",
+#     "Doelgedrag");
+
